$set matout "'matsol.gdx'";
Sets
  w              Weeks in a year
  w_tr(w)        Weeks used in transfer equations (all but last one)
  h              Hours in a week
  h_st(h)        Hours used in storage equations (all but last one)
;

Singleton set
  h_end(h)        Hours used in transfer and reconciliation equations (last hour in week)
;

Scalars
  Pth0    Nominal power consumption [MW]
  PthVar  Maximal allowed power variation [MW]
  EthMax  Maximal allowed thermal energy surplus [MWh]
;

Parameters 
  DAP(w,h)        Day-Ahead electricity price for each hour of the year [EUR per MW]
;

$if exist matdata.gms $include matdata.gms

$GDXIN prices.gdx

$load DAP
$GDXIN

Variables 
  Pth(w,h)             Power uptake in hour h [MW]
  Eth(w,h)             Accumulated thermal energy surplus [MWh]
  C                    Total Cost [EUR]
;

Equations 
  Cost                   Total production cost
  Start_th               Thermal energy surplus in first hour has to equal zero
  Storage_th(w,h)        Thermal energy surplus in hour h
  Transfer_th(w)         Transfer thermal energy surplus to next week
;
  Cost                         ..  C =e= sum((w,h), Pth(w,h) * DAP(w,h));
  Start_th                     ..  Eth("1","1") =e= 0;
  Storage_th(w,h)$h_st(h)      ..  Eth(w,h+1) =e= Eth(w,h) + Pth(w,h) - Pth0;
  Transfer_th(w)$w_tr(w)       ..  Eth(w+1,"1") =e= Eth(w,h_end) + Pth(w,h_end) - Pth0;
  Pth.lo(w,h) = Pth0 - PthVar;
  Pth.up(w,h) = Pth0 + PthVar;

Model    scheduling    / all /;

scheduling.reslim = 100000;

scheduling.optcr = 0.0;

*option MIP = CBC;

  solve scheduling minimizing c using mip;
set stat /modelstat,solvestat/;
parameter returnStat(stat);
returnStat('modelstat') = scheduling.modelstat;
returnStat('solvestat') = scheduling.solvestat;
execute_unload %matout%;